@@ -26,44 +26,102 @@ from zope.testing import doctest
 from zope.testing import renormalizing
 
 
-checker = renormalizing.RENormalizing([
-    # 2.5 changed the way pdb reports exceptions
-    (re.compile(r"<class 'exceptions.(\w+)Error'>:"),
-                r'exceptions.\1Error:'),
+#separated checkers for the different platform,
+#because it s...s to maintain just one
+if sys.platform == 'win32':
+    checker = renormalizing.RENormalizing([
+        # 2.5 changed the way pdb reports exceptions
+        (re.compile(r"<class 'exceptions.(\w+)Error'>:"),
+                    r'exceptions.\1Error:'),
 
-    (re.compile('^> [^\n]+->None$', re.M), '> ...->None'),
-    (re.compile(r"<module>"),(r'?')),
-    (re.compile(r"<type 'exceptions.(\w+)Error'>:"),
-                r'exceptions.\1Error:'),
-    (re.compile("'[A-Za-z]:\\\\"), "'"), # hopefully, we'll make Windows happy
-    (re.compile(r'\\\\'), '/'), # more Windows happiness
-    (re.compile(r'\\'), '/'), # even more Windows happiness
-    (re.compile('/r'), '\\\\r'), # undo damage from previous
-    (re.compile(r'\r'), '\\\\r\n'),
-    (re.compile(r'\d+[.]\d\d\d seconds'), 'N.NNN seconds'),
-    (re.compile(r'\d+[.]\d\d\d s'), 'N.NNN s'),
-    (re.compile(r'\d+[.]\d\d\d{'), 'N.NNN{'),
-    (re.compile('( |")[^\n]+testrunner-ex'), r'\1testrunner-ex'),
-    (re.compile('( |")[^\n]+testrunner.py'), r'\1testrunner.py'),
-    (re.compile(r'> [^\n]*(doc|unit)test[.]py\(\d+\)'),
-                r'\1test.py(NNN)'),
-    (re.compile(r'[.]py\(\d+\)'), r'.py(NNN)'),
-    (re.compile(r'[.]py:\d+'), r'.py:NNN'),
-    (re.compile(r' line \d+,', re.IGNORECASE), r' Line NNN,'),
-    (re.compile(r' line {([a-z]+)}\d+{', re.IGNORECASE), r' Line {\1}NNN{'),
+        #rewrite pdb prompt to ... the current location
+        #windows, py2.4 pdb seems not to put the '>' on doctest locations
+        #therefore we cut it here
+        (re.compile('^> doctest[^\n]+->None$', re.M), '...->None'),
 
-    # omit traceback entries for unittest.py or doctest.py from
-    # output:
-    (re.compile(r'^ +File "[^\n]*(doc|unit)test.py", [^\n]+\n[^\n]+\n',
-                re.MULTILINE),
-     r''),
-    (re.compile(r'^{\w+} +File "{\w+}[^\n]*(doc|unit)test.py{\w+}", [^\n]+\n[^\n]+\n',
-                re.MULTILINE),
-     r''),
-    (re.compile('^> [^\n]+->None$', re.M), '> ...->None'),
-    (re.compile('import pdb; pdb'), 'Pdb()'), # Py 2.3
-    ])
+        #rewrite pdb prompt to ... the current location
+        (re.compile('^> [^\n]+->None$', re.M), '> ...->None'),
 
+        (re.compile(r"<module>"),(r'?')),
+        (re.compile(r"<type 'exceptions.(\w+)Error'>:"),
+                    r'exceptions.\1Error:'),
+
+        (re.compile("'[A-Za-z]:\\\\"), "'"), # hopefully, we'll make Windows happy
+                                             # replaces drives with nothing
+
+        (re.compile(r'\\\\'), '/'), # more Windows happiness
+                                    # double backslashes in coverage???
+
+        (re.compile(r'\\'), '/'), # even more Windows happiness
+                                  # replaces backslashes in paths
+
+        #this is a magic to put linefeeds into the doctest
+        (re.compile('##r##\n'), '\r'),
+
+        (re.compile(r'\d+[.]\d\d\d seconds'), 'N.NNN seconds'),
+        (re.compile(r'\d+[.]\d\d\d s'), 'N.NNN s'),
+        (re.compile(r'\d+[.]\d\d\d{'), 'N.NNN{'),
+        (re.compile('( |")[^\n]+testrunner-ex'), r'\1testrunner-ex'),
+        (re.compile('( |")[^\n]+testrunner.py'), r'\1testrunner.py'),
+        (re.compile(r'> [^\n]*(doc|unit)test[.]py\(\d+\)'),
+                    r'\1test.py(NNN)'),
+        (re.compile(r'[.]py\(\d+\)'), r'.py(NNN)'),
+        (re.compile(r'[.]py:\d+'), r'.py:NNN'),
+        (re.compile(r' line \d+,', re.IGNORECASE), r' Line NNN,'),
+        (re.compile(r' line {([a-z]+)}\d+{', re.IGNORECASE), r' Line {\1}NNN{'),
+
+        # omit traceback entries for unittest.py or doctest.py from
+        # output:
+        (re.compile(r'^ +File "[^\n]*(doc|unit)test.py", [^\n]+\n[^\n]+\n',
+                    re.MULTILINE),
+         r''),
+        (re.compile(r'^{\w+} +File "{\w+}[^\n]*(doc|unit)test.py{\w+}", [^\n]+\n[^\n]+\n',
+                    re.MULTILINE),
+         r''),
+        #(re.compile('^> [^\n]+->None$', re.M), '> ...->None'),
+        (re.compile('import pdb; pdb'), 'Pdb()'), # Py 2.3
+        ])
+else:
+    #*nix
+    checker = renormalizing.RENormalizing([
+        # 2.5 changed the way pdb reports exceptions
+        (re.compile(r"<class 'exceptions.(\w+)Error'>:"),
+                    r'exceptions.\1Error:'),
+
+        #rewrite pdb prompt to ... the current location
+        (re.compile('^> [^\n]+->None$', re.M), '> ...->None'),
+
+        (re.compile(r"<module>"),(r'?')),
+        (re.compile(r"<type 'exceptions.(\w+)Error'>:"),
+                    r'exceptions.\1Error:'),
+
+        #this is a magic to put linefeeds into the doctest
+        #on win it takes one step, linux is crazy about the same...
+        (re.compile('##r##'), r'\r'),
+        (re.compile(r'\r'), '\\\\r\n'),
+
+        (re.compile(r'\d+[.]\d\d\d seconds'), 'N.NNN seconds'),
+        (re.compile(r'\d+[.]\d\d\d s'), 'N.NNN s'),
+        (re.compile(r'\d+[.]\d\d\d{'), 'N.NNN{'),
+        (re.compile('( |")[^\n]+testrunner-ex'), r'\1testrunner-ex'),
+        (re.compile('( |")[^\n]+testrunner.py'), r'\1testrunner.py'),
+        (re.compile(r'> [^\n]*(doc|unit)test[.]py\(\d+\)'),
+                    r'\1test.py(NNN)'),
+        (re.compile(r'[.]py\(\d+\)'), r'.py(NNN)'),
+        (re.compile(r'[.]py:\d+'), r'.py:NNN'),
+        (re.compile(r' line \d+,', re.IGNORECASE), r' Line NNN,'),
+        (re.compile(r' line {([a-z]+)}\d+{', re.IGNORECASE), r' Line {\1}NNN{'),
+
+        # omit traceback entries for unittest.py or doctest.py from
+        # output:
+        (re.compile(r'^ +File "[^\n]*(doc|unit)test.py", [^\n]+\n[^\n]+\n',
+                    re.MULTILINE),
+         r''),
+        (re.compile(r'^{\w+} +File "{\w+}[^\n]*(doc|unit)test.py{\w+}", [^\n]+\n[^\n]+\n',
+                    re.MULTILINE),
+         r''),
+        (re.compile('import pdb; pdb'), 'Pdb()'), # Py 2.3
+        ])
 
 def setUp(test):
     test.globs['saved-sys-info'] = (
@@ -108,7 +166,8 @@ def test_suite():
         optionflags=doctest.ELLIPSIS+doctest.NORMALIZE_WHITESPACE,
         checker=checker),
         doctest.DocTestSuite('zope.testing.testrunner'),
-        doctest.DocTestSuite('zope.testing.testrunner.coverage'),
+        doctest.DocTestSuite('zope.testing.testrunner.coverage',
+            optionflags=doctest.ELLIPSIS+doctest.NORMALIZE_WHITESPACE),
         doctest.DocTestSuite('zope.testing.testrunner.options'),
         doctest.DocTestSuite('zope.testing.testrunner.find'),
         ]
